@@ -1,5 +1,6 @@
 
-from pyniviz.tools import read_pro, create_grid, plot_grid, variable_shortenings, read_smet
+from pyniviz.tools import read_pro, create_grid, plot_grid,\
+    variable_shortenings, read_smet, check_difference_with_conditions
 import datetime
 
 def plot_pro(path,
@@ -12,7 +13,9 @@ def plot_pro(path,
              ymax=None,
              file_name=None,
              c_scheme='plasma_r',
-             yax_shift=0):
+             yax_shift=0,
+             subplot=None,
+             difference_with=None):
 
     """
 
@@ -44,6 +47,12 @@ def plot_pro(path,
                          ymin,
                          ymax)
 
+    if difference_with:
+        check_difference_with_conditions(ymin,ymax,variable)
+        spl2 = read_pro(difference_with, variable)
+        info2 = create_grid(spl2, variable, xmin, xmax, ymin, ymax)
+        info['grid'] = info['grid'] - info2['grid']
+
     plot_grid(info,
                  variable,
                  vmin,
@@ -54,7 +63,9 @@ def plot_pro(path,
                  ymax,
                  file_name,
                  c_scheme,
-                 yax_shift)
+                 yax_shift,
+                 subplot)
+
 
 def plot_smet(path, var): 
 
@@ -62,6 +73,7 @@ def plot_smet(path, var):
 
     df.plot()
 
+
 # SAMPLE VARIABLES
 
 # 'element density (kg m-3)',
